@@ -11,6 +11,7 @@ from skitai import wsgiappservice
 from skitai.corequest import tasks
 import skitai
 from skitai.exceptions import HTTPError
+import uuid
 
 class WAS (wsgiappservice.WAS):
     # mehiods remap ------------------------------------------------
@@ -68,8 +69,10 @@ class WAS (wsgiappservice.WAS):
         signature_ = base64.b64encode (dig).decode ()
         return signature == signature_
 
-    def make_uid (self, s):
-        return base64.encodestring (md5 (s.encode ()).digest ()) [:-3].decode ().replace ('/', '-').replace ('+', '.')
+    def make_uid (self, s = None):
+        if s is None:
+            s = str (uuid.uuid4 ())
+        return base64.encodebytes (md5 (s.encode ()).digest ()) [:-3].decode ().replace ('/', '-').replace ('+', '.')
 
     # JWT token --------------------------------------------------
     def mkjwt (self, claim, salt = None, alg = "HS256"):
